"""
Generate an RSS feed errors in the schedule.
"""
import PyRSS2Gen
import datetime
import sys
import logging
from nowandnext.utils.cmdline import cmdline
from nowandnext.utils.detectos import osinfo
from nowandnext.timezones.utc import utc
from nowandnext.calendar import periods
from nowandnext.calendar.scheduleevent import scheduleevent
from nowandnext.calendar.calQuery import CalQuery, NoCalendarEntry
from nowandnext.calendar.detecterrorsinevent import DetectErrorsInEvent

log = logging.getLogger( __name__ )

class schedule_to_rss( cmdline ):
    
    def __init__(self, configfilepath ):
        self._config = self.getconfiguration(configfilepath)
        self._calargs=( self._config.get('pinger','account'),
                        self._config.get('pinger','password'),
                        self._config.get('pinger','calendar_name'), )
        
        
    def filterandconvertitems(self, calendaritems ):
        
        for calendaritem in calendaritems:
            
            
            report = DetectErrorsInEvent( calendaritem )
            
            if report.getErrorCount() > 0:
                item = PyRSS2Gen.RSSItem(
                     title = calendaritem.getTitle(),
                     link = calendaritem.getWebLink(),
                     description = report.getErrorHTMLList(),
                     guid = calendaritem.getWebLink(),
                     pubDate = calendaritem.getPublishDate() )
                yield item
        
    def __call__(self):
        calendaritems = self.getcalendaritems()
        
        rss = PyRSS2Gen.RSS2(
            title = self._config.get("errors", "title"),
            link = self._config.get("errors", "link"),
            description = self._config.get("errors", "description"),    
            lastBuildDate = datetime.datetime.now(),
            items = self.filterandconvertitems( calendaritems ) )
        
        rss.write_xml( sys.stdout, encoding="utf8" )
        
    def getcalendaritems(self):
        now = datetime.datetime.now( utc )
        sometimeinthefuture = now + ( periods.onehour * 24 * 7 )

        cal = CalQuery( *self._calargs )
        events = []
        events.extend( [a for a in cal.getEvents( now , sometimeinthefuture ) ] )
        return events

def main( ):
    logging.basicConfig()
    options, args = schedule_to_rss.mkParser().parse_args()
    if options.verbose:
        logging.getLogger("").setLevel(logging.INFO)
    else:
        logging.getLogger("").setLevel(logging.WARN)
    
    os_spesific_handler = osinfo.get_logger("Pinger")
    os_spesific_handler.setLevel( logging.WARN )
    logging.getLogger("").addHandler( os_spesific_handler )

    # schedule_to_rss.copyrightmessage()

    s2r = schedule_to_rss( options.configfilepath )
    s2r()
    
if __name__ == "__main__":
    main()
    